==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/is-IS/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirm Bulk Delete Assets',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Review the assets for bulk deletion below. Once deleted, these assets can be restored, but they will no longer be associated with any users they are currently assigned to.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'You are about to delete :asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Bulk Update Assets',
    'bulk_update_help'	=> 'This form allows you to update multiple assets at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Ráðstafað til',
    'checkout_date'		=> 'Ráðstöfunardagsetning',
    'checkin_date'		=> 'Skiladagsetning',
    'checkout_to'		=> 'Ráðstöfun til',
    'cost'				=> 'Innkaupsverð',
    'create'			=> 'Skrá eign',
    'date'				=> 'Innkaups dagsetning',
    'depreciation'	    => 'Fyrningarflokkur',
    'depreciates_on'	=> 'Afskriftir á',
    'default_location'	=> 'Sjálfgefin staðsetning',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL Dags',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Áætluð skiladagsetning',
    'expires'			=> 'Expires (útrunnið)',
    'fully_depreciated'	=> 'Að fullu afskrifað',
    'help_checkout'		=> 'Ef þú vilt ráðstafa þessari eign strax skaltu velja "Tilbúin til ráðstöfunar" úr listanum yfir stöður hér að ofan. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Framleiðandi',
    'model'				=> 'Tegund',
    'months'			=> 'mánuðir',
    'name'				=> 'Heiti eignar',
    'notes'				=> 'Athugasemdir',
    'order'				=> 'Pöntunarnúmer',
    'qr'				=> 'QR kóði',
    'requestable'		=> 'Notendur mega biðja um þessa eign',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Veldu stöðu',
    'serial'			=> 'Raðnúmer',
    'status'			=> 'Staða',
    'tag'				=> 'Eignamerking',
    'update'			=> 'Eign uppfærð',
    'warranty'			=> 'Ábyrgð',
        'warranty_expires'		=> 'Ábyrgð gildir til',
    'years'				=> 'ár',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Uppfæra aðeins núverandi staðsetningu',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Viðbótarupplýsingar',
    'order_details'   => 'Innkaupaupplýsingar'
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/is-IS/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Confirm Bulk Delete Assets',
    'bulk_restore'      => 'Confirm Bulk Restore Assets', 
  'bulk_delete_help'	=> 'Review the assets for bulk deletion below. Once deleted, these assets can be restored, but they will no longer be associated with any users they are currently assigned to.',
  'bulk_restore_help'	=> 'Review the assets for bulk restoration below. Once restored, these assets will not be associated with any users they were previously assigned to.',
  'bulk_delete_warn'	=> 'You are about to delete :asset_count assets.',
  'bulk_restore_warn'	=> 'You are about to restore :asset_count assets.',
    'bulk_update'		=> 'Bulk Update Assets',
    'bulk_update_help'	=> 'This form allows you to update multiple assets at once. Only fill in the fields you need to change. Any fields left blank will remain unchanged. ',
    'bulk_update_warn'	=> 'You are about to edit the properties of a single asset.|You are about to edit the properties of :asset_count assets.',
    'bulk_update_with_custom_field' => 'Note the assets are :asset_model_count different types of models.',
    'bulk_update_model_prefix' => 'On Models', 
    'bulk_update_custom_field_unique' => 'This is a unique field and can not be bulk edited.',
    'checkedout_to'		=> 'Ráðstafað til',
    'checkout_date'		=> 'Ráðstöfunardagsetning',
    'checkin_date'		=> 'Skiladagsetning',
    'checkout_to'		=> 'Ráðstöfun til',
    'cost'				=> 'Innkaupsverð',
    'create'			=> 'Skrá eign',
    'date'				=> 'Innkaups dagsetning',
    'depreciation'	    => 'Fyrningarflokkur',
    'depreciates_on'	=> 'Afskriftir á',
    'default_location'	=> 'Sjálfgefin staðsetning',
    'default_location_phone' => 'Default Location Phone',
    'eol_date'			=> 'EOL Dags',
    'eol_rate'			=> 'EOL Rate',
    'expected_checkin'  => 'Áætluð skiladagsetning',
    'expires'			=> 'Expires (útrunnið)',
    'fully_depreciated'	=> 'Að fullu afskrifað',
    'help_checkout'		=> 'Ef þú vilt ráðstafa þessari eign strax skaltu velja "Tilbúin til ráðstöfunar" úr listanum yfir stöður hér að ofan. ',
    'mac_address'		=> 'MAC Address',
    'manufacturer'		=> 'Framleiðandi',
    'model'				=> 'Tegund',
    'months'			=> 'mánuðir',
    'name'				=> 'Heiti eignar',
    'notes'				=> 'Athugasemdir',
    'order'				=> 'Pöntunarnúmer',
    'qr'				=> 'QR kóði',
    'requestable'		=> 'Notendur mega biðja um þessa eign',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Veldu stöðu',
    'serial'			=> 'Raðnúmer',
    'status'			=> 'Staða',
    'tag'				=> 'Eignamerking',
    'update'			=> 'Eign uppfærð',
    'warranty'			=> 'Ábyrgð',
        'warranty_expires'		=> 'Ábyrgð gildir til',
    'years'				=> 'ár',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_location_update_actual' => 'Uppfæra aðeins núverandi staðsetningu',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing... (This might take a bit of time on large files)',
    'optional_infos'  => 'Viðbótarupplýsingar',
    'order_details'   => 'Innkaupaupplýsingar',
    'calc_eol'    => 'If nulling the EOL date, use automatic EOL calculation based on the purchase date and EOL rate.',
];
